package ic

import java.io.BufferedReader
import java.io.FileReader
import java.io.IOException
import ic.parser._
import ic.lex.Lexer

/**
 * The main class for the IC Compiler.  The Compiler
 * expects the name of the file to process on the command line,
 * as in:
 * <pre>
 *   scala ic.Compiler test.ic
 * </pre>
 * An optional flag <tt>-d<tt> can be provided, as in:
 * <pre>
 *   scala ic.Compiler -d test.ic
 * </pre>
 * In this case, messages created by calling {@link ic.Util#debug(String)}
 * or {@link ic.Util#debug(String, Object...)} will be printed to the
 * terminal.  If <tt>-d</tt> is not provided, these messages will
 * be silently ignored.
 */
object Compiler {

	def main(args : Array[String]) = {

		var n = 0;

		// If first command line argument is -d, turn on debugging
		if (args.length > n && args(n).equals("-d")) {
			Util.debug = true;
			n = n + 1;
		}
		
		// Get name of file
		if (args.length == n) {
			System.out.println("No file given.");			
		} else {
			val file = args(n);

			// example of debug message: This message will only be printed if
			// you provide "-d" on the command line.
			Util.debug("Processing %s...", file);

			// TODO: finish me:
			val programParser = new parser(new Lexer(new FileReader(file)));
			val resultValue = programParser.parse().value;
			println(resultValue);
		}

	}

}
